@@ -31,7 +31,6 @@ class InstanceEC2(Instance):
         self.project = None
         self.zone = self.get_zone()
         self.region = self.get_region()
-        self.datacenter = self.get_datacenter()
         self.instance_id = self.get_instance_id()
 
     def load_tags(self, **kwargs):
@@ -50,10 +49,11 @@ class InstanceEC2(Instance):
     def get_region(self, **kwargs):
         return self.get_zone()[:-1]
 
-    def get_datacenter(self, **kwargs):
-        region = self.get_region()
-
-        return self.DATACENTERS[region]
+    def datacenter(self, **kwargs):
+        if "datacenter" in self.tags:
+            return self.tags['datacenter']
+        else:
+            return None
 
     def get_tags(self, *kwargs):
         tags = {}
@@ -62,9 +62,7 @@ class InstanceEC2(Instance):
         instance = ec2.Instance(self.instance_id)
         for tag in instance.tags:
             if ":" in tag['Key']:
-                # True skips this block
                 True
-                # print("skip adding %s because is has ':' in key" % (tag['Key']))
             elif "," in tag['Value']:
                 tags[tag['Key']] = tag['Value'].split(",")
             else:
